@@ -1,9 +1,8 @@
 /***************************************************************************
-    smb4kcustomoptionsmanager_p - Private helper classes for 
-    Smb4KCustomOptionsManager class
+    Private helper classes for Smb4KCustomOptionsManager class
                              -------------------
     begin                : Fr 29 Apr 2011
-    copyright            : (C) 2011-2015 by Alexander Reinholdt
+    copyright            : (C) 2011-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -32,16 +31,17 @@
 #include "smb4kcustomoptions.h"
 
 // Qt includes
-#include <QtCore/QList>
-#include <QtGui/QCheckBox>
+#include <QList>
+#include <QCheckBox>
+#include <QDialog>
+#include <QSpinBox>
+#include <QPushButton>
 
 // KDE includes
-#include <kdialog.h>
-#include <klineedit.h>
-#include <knuminput.h>
-#include <kcombobox.h>
+#include <KCompletion/KLineEdit>
+#include <KCompletion/KComboBox>
 
-class Smb4KCustomOptionsDialog : public KDialog
+class Smb4KCustomOptionsDialog : public QDialog
 {
   Q_OBJECT
   
@@ -49,8 +49,8 @@ class Smb4KCustomOptionsDialog : public KDialog
     /**
      * Constructor
      */
-    explicit Smb4KCustomOptionsDialog( Smb4KCustomOptions *options,
-                                       QWidget *parent = 0 );
+    explicit Smb4KCustomOptionsDialog(Smb4KCustomOptions *options,
+                                       QWidget *parent = 0);
     
     /**
      * Destructor
@@ -61,22 +61,24 @@ class Smb4KCustomOptionsDialog : public KDialog
     void slotSetDefaultValues();
     void slotCheckValues();
     void slotOKClicked();
-    void slotEnableWOLFeatures( const QString &mac );
+    void slotEnableWOLFeatures(const QString &mac);
     
   private:
     void setupView();
     bool checkDefaultValues();
     void setDefaultValues();
     void saveValues();
+    QPushButton *m_restore_button;
+    QPushButton *m_ok_button;
+    QPushButton *m_cancel_button;
     Smb4KCustomOptions *m_options;
     QCheckBox *m_remount;
-    KIntNumInput *m_smb_port;
+    QSpinBox *m_smb_port;
 #if defined(Q_OS_LINUX)
-    KIntNumInput *m_fs_port;
+    QSpinBox *m_fs_port;
     KComboBox *m_security_mode;
     KComboBox *m_write_access;
 #endif
-    KComboBox *m_protocol_hint;
     KComboBox *m_user_id;
     KComboBox *m_group_id;
     QCheckBox *m_kerberos;
