@@ -1,9 +1,8 @@
 /***************************************************************************
-    smb4kdeclarative - This class provides the interface for Plasma and
-    QtQuick
+    This class provides the interface for Plasma and QtQuick
                              -------------------
     begin                : Mo 02 Sep 2013
-    copyright            : (C) 2013-2014 by Alexander Reinholdt
+    copyright            : (C) 2013-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -45,13 +44,14 @@
 #include "smb4kprofilemanager.h"
 
 // Qt includes
-#include <QtCore/QDebug>
+#include <QDebug>
+#include <QTest>
 
 using namespace Smb4KGlobal;
 
 
 Smb4KDeclarative::Smb4KDeclarative(QObject* parent)
-: QObject(parent), d( new Smb4KDeclarativePrivate )
+: QObject(parent), d(new Smb4KDeclarativePrivate)
 {
   // Initialize the core.
   Smb4KGlobal::initCore(true, false);
@@ -124,53 +124,53 @@ Smb4KDeclarative::~Smb4KDeclarative()
 }
 
 
-QDeclarativeListProperty<Smb4KNetworkObject> Smb4KDeclarative::workgroups()
+QQmlListProperty<Smb4KNetworkObject> Smb4KDeclarative::workgroups()
 {
-  return QDeclarativeListProperty<Smb4KNetworkObject>(this, d->workgroupObjects);
+  return QQmlListProperty<Smb4KNetworkObject>(this, d->workgroupObjects);
 }
 
 
-QDeclarativeListProperty<Smb4KNetworkObject> Smb4KDeclarative::hosts()
+QQmlListProperty<Smb4KNetworkObject> Smb4KDeclarative::hosts()
 {
-  return QDeclarativeListProperty<Smb4KNetworkObject>(this, d->hostObjects);
+  return QQmlListProperty<Smb4KNetworkObject>(this, d->hostObjects);
 }
 
 
-QDeclarativeListProperty<Smb4KNetworkObject> Smb4KDeclarative::shares()
+QQmlListProperty<Smb4KNetworkObject> Smb4KDeclarative::shares()
 {
-  return QDeclarativeListProperty<Smb4KNetworkObject>(this, d->shareObjects);
+  return QQmlListProperty<Smb4KNetworkObject>(this, d->shareObjects);
 }
 
 
-QDeclarativeListProperty<Smb4KNetworkObject> Smb4KDeclarative::mountedShares()
+QQmlListProperty<Smb4KNetworkObject> Smb4KDeclarative::mountedShares()
 {
-  return QDeclarativeListProperty<Smb4KNetworkObject>(this, d->mountedObjects);
+  return QQmlListProperty<Smb4KNetworkObject>(this, d->mountedObjects);
 }
 
 
-QDeclarativeListProperty<Smb4KBookmarkObject> Smb4KDeclarative::bookmarks()
+QQmlListProperty<Smb4KBookmarkObject> Smb4KDeclarative::bookmarks()
 {
-  return QDeclarativeListProperty<Smb4KBookmarkObject>(this, d->bookmarkObjects);
+  return QQmlListProperty<Smb4KBookmarkObject>(this, d->bookmarkObjects);
 }
 
 
-QDeclarativeListProperty<Smb4KBookmarkObject> Smb4KDeclarative::bookmarkGroups()
+QQmlListProperty<Smb4KBookmarkObject> Smb4KDeclarative::bookmarkGroups()
 {
-  return QDeclarativeListProperty<Smb4KBookmarkObject>(this, d->bookmarkGroupObjects);
+  return QQmlListProperty<Smb4KBookmarkObject>(this, d->bookmarkGroupObjects);
 }
 
 
-QDeclarativeListProperty<Smb4KProfileObject> Smb4KDeclarative::profiles()
+QQmlListProperty<Smb4KProfileObject> Smb4KDeclarative::profiles()
 {
-  return QDeclarativeListProperty<Smb4KProfileObject>(this, d->profileObjects);
+  return QQmlListProperty<Smb4KProfileObject>(this, d->profileObjects);
 }
 
 
-void Smb4KDeclarative::lookup( Smb4KNetworkObject *object )
+void Smb4KDeclarative::lookup(Smb4KNetworkObject *object)
 {
-  if ( object )
+  if (object)
   {
-    switch ( object->type() )
+    switch (object->type())
     {
       case Network:
       {
@@ -180,11 +180,11 @@ void Smb4KDeclarative::lookup( Smb4KNetworkObject *object )
       case Workgroup:
       {
         // Check if the workgroup is known.
-        Smb4KWorkgroup *workgroup = findWorkgroup( object->url().host().toUpper() );
+        Smb4KWorkgroup *workgroup = findWorkgroup(object->url().host().toUpper());
         
-        if ( workgroup )
+        if (workgroup)
         {
-          Smb4KScanner::self()->lookupDomainMembers( workgroup );
+          Smb4KScanner::self()->lookupDomainMembers(workgroup);
         }
         else
         {
@@ -195,11 +195,11 @@ void Smb4KDeclarative::lookup( Smb4KNetworkObject *object )
       case Host:
       {
         // Check if the host is known.
-        Smb4KHost *host = findHost( object->url().host().toUpper() );
+        Smb4KHost *host = findHost(object->url().host().toUpper());
         
-        if ( host )
+        if (host)
         {
-          Smb4KScanner::self()->lookupShares( host );
+          Smb4KScanner::self()->lookupShares(host);
         }
         else
         {
@@ -220,25 +220,25 @@ void Smb4KDeclarative::lookup( Smb4KNetworkObject *object )
   }
   else
   {
-    // If the object is NULL, scan the whole network.
+    // If the object is 0, scan the whole network.
     Smb4KScanner::self()->lookupDomains();
   }
 }
 
 
-Smb4KNetworkObject *Smb4KDeclarative::findNetworkItem( const QUrl &url, int type )
+Smb4KNetworkObject *Smb4KDeclarative::findNetworkItem(const QUrl &url, int type)
 {
-  Smb4KNetworkObject *object = NULL;
+  Smb4KNetworkObject *object = 0;
   
-  if ( url.isValid() )
+  if (url.isValid())
   {  
-    switch ( type )
+    switch (type)
     {
       case Workgroup:
       {
-        for ( int i = 0; i < d->workgroupObjects.size(); ++i )
+        for (int i = 0; i < d->workgroupObjects.size(); ++i)
         {
-          if ( url == d->workgroupObjects.at( i )->url() )
+          if (url == d->workgroupObjects.at(i)->url())
           {
             object = d->workgroupObjects[i];
             break;
@@ -252,9 +252,9 @@ Smb4KNetworkObject *Smb4KDeclarative::findNetworkItem( const QUrl &url, int type
       }
       case Host:
       {
-        for ( int i = 0; i < d->hostObjects.size(); ++i )
+        for (int i = 0; i < d->hostObjects.size(); ++i)
         {
-          if ( url == d->hostObjects.at( i )->url() )
+          if (url == d->hostObjects.at(i)->url())
           {
             object = d->hostObjects[i];
             break;
@@ -268,9 +268,9 @@ Smb4KNetworkObject *Smb4KDeclarative::findNetworkItem( const QUrl &url, int type
       }
       case Share:
       {
-        for ( int i = 0; i < d->shareObjects.size(); ++i )
+        for (int i = 0; i < d->shareObjects.size(); ++i)
         {
-          if ( url == d->shareObjects.at( i )->url() )
+          if (url == d->shareObjects.at(i)->url())
           {
             object = d->shareObjects[i];
             break;
@@ -303,42 +303,45 @@ void Smb4KDeclarative::openMountDialog(QWidget* parent)
 }
 
 
-void Smb4KDeclarative::mount(const QUrl& url)
+void Smb4KDeclarative::mount(Smb4KNetworkObject *object)
 {
-  //
-  // FIXME - Smb4K 1.2: Use Smb4KNetworkObject as argument
-  // 
-  if ( url.isValid() && !url.path().isEmpty() )
+  if (object && object->type() == Smb4KNetworkObject::Share)
   {
-    QString share_name = url.path();
+    QString shareName = object->url().path();
       
-    if ( share_name.startsWith( '/' ) )
+    if (shareName.startsWith('/'))
     {
-      share_name = share_name.mid( 1, -1 );
+      shareName = shareName.mid(1, -1);
     }
     else
     {
       // Do nothing
     }
       
-    Smb4KShare *share = findShare( share_name, url.host() );
+    Smb4KShare *share = findShare("//"+object->hostName()+'/'+object->shareName(), object->workgroupName());
     
-    if ( share )
+    if (share)
     {
-      Smb4KMounter::self()->mountShare( share );
+      Smb4KMounter::self()->mountShare(share);
     }
     else
     {
       // If the share is not in the global list of shares,
       // try the list of bookmarks.
-      QString unc( "//"+url.host()+"/"+share_name );
-      Smb4KBookmark *bookmark = Smb4KBookmarkHandler::self()->findBookmarkByUNC( unc );
+      QString unc("//"+object->hostName()+"/"+object->shareName());
+      Smb4KBookmark *bookmark = Smb4KBookmarkHandler::self()->findBookmarkByUNC(unc);
       share = new Smb4KShare();
-      share->setURL( url );
-      share->setWorkgroupName( bookmark->workgroupName() );
-      share->setHostIP( bookmark->hostIP() );
-      Smb4KMounter::self()->mountShare( share );
-      delete share;
+      share->setURL(object->url());
+      share->setWorkgroupName(bookmark->workgroupName());
+      share->setHostIP(bookmark->hostIP());
+      Smb4KMounter::self()->mountShare(share);
+      
+      while (Smb4KMounter::self()->isRunning())
+      {
+        QTest::qWait(50);
+      }
+      
+      delete share;      
     }
   }
   else
@@ -348,22 +351,22 @@ void Smb4KDeclarative::mount(const QUrl& url)
 }
 
 
-void Smb4KDeclarative::unmount(const QUrl& mountpoint)
+void Smb4KDeclarative::unmount(Smb4KNetworkObject *object)
 {
-  //
-  // FIXME - Smb4K 1.2: Use Smb4KNetworkObject as argument
-  // 
-  if ( mountpoint.isValid() )
+  if (object && object->type())
   {
-    Smb4KShare *share = findShareByPath( mountpoint.path() );
-    
-    if ( share )
+    if (object->mountpoint().isValid())
     {
-      Smb4KMounter::self()->unmountShare( share );
-    }
-    else
-    {
-      // Do nothing
+      Smb4KShare *share = findShareByPath(object->mountpoint().path());
+      
+      if (share)
+      {
+        Smb4KMounter::self()->unmountShare(share);
+      }
+      else
+      {
+        // Do nothing
+      }
     }
   }
   else
@@ -375,32 +378,32 @@ void Smb4KDeclarative::unmount(const QUrl& mountpoint)
 
 void Smb4KDeclarative::unmountAll()
 {
-  Smb4KMounter::self()->unmountAllShares();
+  Smb4KMounter::self()->unmountAllShares(false, 0);
 }
 
 
 Smb4KNetworkObject* Smb4KDeclarative::findMountedShare(const QUrl& url, bool exactMatch)
 {
-  Smb4KNetworkObject *object = NULL;
+  Smb4KNetworkObject *object = 0;
   
-  if ( url.isValid() )
+  if (url.isValid())
   {
-    KUrl u1 = url;
-    u1.setUserInfo( QString() );
-    u1.setPort( -1 );
+    QUrl u1 = url;
+    u1.setUserInfo(QString());
+    u1.setPort(-1);
     
-    for ( int i = 0; i < d->mountedObjects.size(); ++i )
+    for (int i = 0; i < d->mountedObjects.size(); ++i)
     {
-      KUrl u2 =  d->mountedObjects.at( i )->url();
-      u2.setUserInfo( QString() );
-      u2.setPort( -1 );
+      QUrl u2 =  d->mountedObjects.at(i)->url();
+      u2.setUserInfo(QString());
+      u2.setPort(-1);
       
-      if ( url == d->mountedObjects.at( i )->url() )
+      if (url == d->mountedObjects.at(i)->url())
       {
         object = d->mountedObjects[i];
         break;
       }
-      else if ( u1 == u2 && !exactMatch )
+      else if (u1 == u2 && !exactMatch)
       {
         object = d->mountedObjects[i];
         continue;
@@ -422,25 +425,13 @@ Smb4KNetworkObject* Smb4KDeclarative::findMountedShare(const QUrl& url, bool exa
 
 void Smb4KDeclarative::print(Smb4KNetworkObject* object)
 {
-  if ( object )
+  if (object && object->type() == Smb4KNetworkObject::Share)
   {
-    QString host = object->url().host();
-    QString name = object->url().path();
+    Smb4KShare *printer = findShare("//"+object->hostName()+"/"+object->shareName(), object->workgroupName());
     
-    if ( name.startsWith( '/' ) )
+    if (printer)
     {
-      name = name.mid( 1 );
-    }
-    else
-    {
-      // Do nothing
-    }
-    
-    Smb4KShare *printer = findShare( name, host );
-    
-    if ( printer )
-    {
-      Smb4KPrint::self()->print( printer, 0 );
+      Smb4KPrint::self()->print(printer, 0);
     }
     else
     {
@@ -456,17 +447,17 @@ void Smb4KDeclarative::print(Smb4KNetworkObject* object)
 
 void Smb4KDeclarative::addBookmark(Smb4KNetworkObject* object)
 {
-  if ( object )
+  if (object)
   {
     QList<Smb4KShare *> shares; 
     
     // First, search the list of shares gathered by 
     // the scanner.
-    for ( int i = 0; i < sharesList().size(); ++i )
+    for (int i = 0; i < sharesList().size(); ++i)
     {
-      if ( sharesList().at( i )->url() == object->url() )
+      if (sharesList().at(i)->url() == object->url())
       {
-        shares << sharesList().at( i );
+        shares << sharesList().at(i);
         break;
       }
       else
@@ -477,13 +468,13 @@ void Smb4KDeclarative::addBookmark(Smb4KNetworkObject* object)
     
     // Second, if the list is still empty, try the list 
     // of mounted shares.
-    if ( shares.isEmpty() )
+    if (shares.isEmpty())
     {
-      for ( int i = 0; i < mountedSharesList().size(); ++i )
+      for (int i = 0; i < mountedSharesList().size(); ++i)
       {
-        if ( mountedSharesList().at( i )->url() == object->url() )
+        if (mountedSharesList().at(i)->url() == object->url())
         {
-          shares << mountedSharesList().at( i );
+          shares << mountedSharesList().at(i);
           break;
         }
         else
@@ -498,9 +489,9 @@ void Smb4KDeclarative::addBookmark(Smb4KNetworkObject* object)
     }
     
     // Now add the share.
-    if ( !shares.isEmpty() )
+    if (!shares.isEmpty())
     {
-      Smb4KBookmarkHandler::self()->addBookmarks( shares, 0 );
+      Smb4KBookmarkHandler::self()->addBookmarks(shares, 0);
     }
     else
     {
@@ -516,16 +507,16 @@ void Smb4KDeclarative::addBookmark(Smb4KNetworkObject* object)
 
 void Smb4KDeclarative::removeBookmark(Smb4KBookmarkObject* object)
 {
-  if ( object )
+  if (object)
   {
     // Find the bookmark in the list and remove it.
-    QString path = (object->url().path().startsWith( '/' ) ? object->url().path().remove( 0, 1 ) : object->url().path());
-    QString unc = QString( "//%1/%2" ).arg( object->url().host().toUpper() ).arg( path );
-    Smb4KBookmark *bookmark = Smb4KBookmarkHandler::self()->findBookmarkByUNC( unc );
+    QString path = (object->url().path().startsWith('/') ? object->url().path().remove(0, 1) : object->url().path());
+    QString unc = QString("//%1/%2").arg(object->url().host().toUpper()).arg(path);
+    Smb4KBookmark *bookmark = Smb4KBookmarkHandler::self()->findBookmarkByUNC(unc);
     
-    if ( bookmark )
+    if (bookmark)
     {
-      Smb4KBookmarkHandler::self()->removeBookmark( bookmark );
+      Smb4KBookmarkHandler::self()->removeBookmark(bookmark);
     }
     else
     {
@@ -553,17 +544,17 @@ void Smb4KDeclarative::editBookmarks()
 
 void Smb4KDeclarative::openCustomOptionsDialog(Smb4KNetworkObject *object)
 {
-  if ( object )
+  if (object)
   {
-    switch ( object->type() )
+    switch (object->type())
     {
       case Host:
       {
-        for ( int i = 0; i < hostsList().size(); ++i )
+        for (int i = 0; i < hostsList().size(); ++i)
         {
-          if ( hostsList().at( i )->url() == object->url() )
+          if (hostsList().at(i)->url() == object->url())
           {
-            Smb4KCustomOptionsManager::self()->openCustomOptionsDialog( hostsList().at( i ) );
+            Smb4KCustomOptionsManager::self()->openCustomOptionsDialog(hostsList().at(i));
             break;
           }
           else
@@ -575,11 +566,11 @@ void Smb4KDeclarative::openCustomOptionsDialog(Smb4KNetworkObject *object)
       }
       case Share:
       {
-        for ( int i = 0; i < sharesList().size(); ++i )
+        for (int i = 0; i < sharesList().size(); ++i)
         {
-          if ( sharesList().at( i )->url() == object->url() )
+          if (sharesList().at(i)->url() == object->url())
           {
-            Smb4KCustomOptionsManager::self()->openCustomOptionsDialog( sharesList().at( i ) );
+            Smb4KCustomOptionsManager::self()->openCustomOptionsDialog(sharesList().at(i));
             break;
           }
           else
@@ -673,14 +664,14 @@ bool Smb4KDeclarative::profileUsage() const
 void Smb4KDeclarative::slotWorkgroupsListChanged()
 {
   // (Re)fill the list of workgroup objects.
-  while ( !d->workgroupObjects.isEmpty() )
+  while (!d->workgroupObjects.isEmpty())
   {
     delete d->workgroupObjects.takeFirst();
   }
 
-  for ( int i = 0; i < workgroupsList().size(); ++i )
+  for (int i = 0; i < workgroupsList().size(); ++i)
   {
-    d->workgroupObjects << new Smb4KNetworkObject( workgroupsList().at( i ) );
+    d->workgroupObjects << new Smb4KNetworkObject(workgroupsList().at(i));
   }
   
   emit workgroupsListChanged();
@@ -690,14 +681,14 @@ void Smb4KDeclarative::slotWorkgroupsListChanged()
 void Smb4KDeclarative::slotHostsListChanged()
 {
   // (Re)fill the list of host object.
-  while ( !d->hostObjects.isEmpty() )
+  while (!d->hostObjects.isEmpty())
   {
     delete d->hostObjects.takeFirst();
   }
 
-  for ( int i = 0; i < hostsList().size(); ++i )
+  for (int i = 0; i < hostsList().size(); ++i)
   {
-    d->hostObjects << new Smb4KNetworkObject( hostsList().at( i ) );
+    d->hostObjects << new Smb4KNetworkObject(hostsList().at(i));
   } 
   
   emit hostsListChanged();
@@ -707,14 +698,14 @@ void Smb4KDeclarative::slotHostsListChanged()
 void Smb4KDeclarative::slotSharesListChanged()
 {
   // (Re)fill the list of share objects.
-  while ( !d->shareObjects.isEmpty() )
+  while (!d->shareObjects.isEmpty())
   {
     delete d->shareObjects.takeFirst();
   }
 
-  for ( int i = 0; i < sharesList().size(); ++i )
+  for (int i = 0; i < sharesList().size(); ++i)
   {
-    d->shareObjects << new Smb4KNetworkObject( sharesList().at( i ) );
+    d->shareObjects << new Smb4KNetworkObject(sharesList().at(i));
   }
   
   emit sharesListChanged();
@@ -724,14 +715,14 @@ void Smb4KDeclarative::slotSharesListChanged()
 void Smb4KDeclarative::slotMountedSharesListChanged()
 {
   // (Re)fill the list of share objects.
-  while ( !d->mountedObjects.isEmpty() )
+  while (!d->mountedObjects.isEmpty())
   {
     delete d->mountedObjects.takeFirst();
   }
 
-  for ( int i = 0; i < mountedSharesList().size(); ++i )
+  for (int i = 0; i < mountedSharesList().size(); ++i)
   {
-    d->mountedObjects << new Smb4KNetworkObject( mountedSharesList().at( i ) );
+    d->mountedObjects << new Smb4KNetworkObject(mountedSharesList().at(i));
   }
   
   emit mountedSharesListChanged();
@@ -741,24 +732,24 @@ void Smb4KDeclarative::slotMountedSharesListChanged()
 void Smb4KDeclarative::slotBookmarksListChanged()
 {
   // (Re)fill the list of bookmark and group objects.
-  while ( !d->bookmarkObjects.isEmpty() )
+  while (!d->bookmarkObjects.isEmpty())
   {
     delete d->bookmarkObjects.takeFirst();
   }
   
-  while ( !d->bookmarkGroupObjects.isEmpty() )
+  while (!d->bookmarkGroupObjects.isEmpty())
   {
     delete d->bookmarkGroupObjects.takeFirst();
   }
   
-  for ( int i = 0; i < Smb4KBookmarkHandler::self()->bookmarksList().size(); ++i )
+  for (int i = 0; i < Smb4KBookmarkHandler::self()->bookmarksList().size(); ++i)
   {
-    d->bookmarkObjects << new Smb4KBookmarkObject( Smb4KBookmarkHandler::self()->bookmarksList().at( i ) );
+    d->bookmarkObjects << new Smb4KBookmarkObject(Smb4KBookmarkHandler::self()->bookmarksList().at(i));
   }
   
-  for ( int i = 0; i < Smb4KBookmarkHandler::self()->groupsList().size(); ++i )
+  for (int i = 0; i < Smb4KBookmarkHandler::self()->groupsList().size(); ++i)
   {
-    d->bookmarkGroupObjects << new Smb4KBookmarkObject( Smb4KBookmarkHandler::self()->groupsList().at( i ) );
+    d->bookmarkGroupObjects << new Smb4KBookmarkObject(Smb4KBookmarkHandler::self()->groupsList().at(i));
   }
   
   emit bookmarksListChanged();
@@ -815,6 +806,3 @@ void Smb4KDeclarative::slotProfileUsageChanged(bool /*use*/)
   emit profileUsageChanged();
 }
 
-
-
-#include "smb4kdeclarative.moc"
