@@ -1,9 +1,9 @@
 /***************************************************************************
-    smb4knetworkobject  -  This class derives from QObject and
-    encapsulates the network items. It is for use with QtQuick.
+    This class derives from QObject and encapsulates the network items. 
+    It is for use with QtQuick.
                              -------------------
     begin                : Fr Mär 02 2012
-    copyright            : (C) 2012-2015 by Alexander Reinholdt
+    copyright            : (C) 2012-2016 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -34,14 +34,11 @@
 #include "smb4kglobal.h"
 
 // Qt includes
-#include <QtCore/QObject>
-#include <QtCore/QString>
-#include <QtCore/QScopedPointer>
-#include <QtGui/QIcon>
-
-// KDE includes
-#include <kdemacros.h>
-#include <kurl.h>
+#include <QObject>
+#include <QString>
+#include <QScopedPointer>
+#include <QUrl>
+#include <QIcon>
 
 // forward declaration
 class Smb4KNetworkObjectPrivate;
@@ -56,7 +53,7 @@ class Smb4KNetworkObjectPrivate;
  */
 
 
-class KDE_EXPORT Smb4KNetworkObject : public QObject
+class Q_DECL_EXPORT Smb4KNetworkObject : public QObject
 {
   Q_OBJECT
   Q_PROPERTY(NetworkItem type READ type WRITE setType NOTIFY changed)
@@ -87,7 +84,7 @@ class KDE_EXPORT Smb4KNetworkObject : public QObject
       Workgroup = Smb4KGlobal::Workgroup,
       Host = Smb4KGlobal::Host,
       Share = Smb4KGlobal::Share,
-      Unknown = Smb4KGlobal::Unknown };
+      Unknown = Smb4KGlobal::UnknownNetworkItem };
     
     /**
      * Constructor for a workgroup.
@@ -245,21 +242,21 @@ class KDE_EXPORT Smb4KNetworkObject : public QObject
      * 
      * @returns the item's URL
      */
-    KUrl url() const;
+    QUrl url() const;
     
     /**
      * Return the URL of the parent item.
      * 
      * @returns the item's parent URL
      */
-    KUrl parentURL() const;
+    QUrl parentURL() const;
     
     /**
      * Set the URL of this network item.
      * 
      * @param url         The URL
      */
-    void setURL(const KUrl &url);
+    void setURL(const QUrl &url);
     
     /**
      * This function returns TRUE if the network item is a share and it is
@@ -304,7 +301,7 @@ class KDE_EXPORT Smb4KNetworkObject : public QObject
      * 
      * @returns the mount point of a share.
      */
-    KUrl mountpoint() const;
+    QUrl mountpoint() const;
     
     /**
      * Set the mountpoint for this network item. This is only reasonable with a
@@ -312,7 +309,7 @@ class KDE_EXPORT Smb4KNetworkObject : public QObject
      * 
      * @param mountpoint  The mountpoint
      */
-    void setMountpoint(const KUrl &url);
+    void setMountpoint(const QUrl &url);
     
   Q_SIGNALS:
     /**
